<?php
if( !class_exists('DTDoctorPostType') ) {
	class DTDoctorPostType {

		function __construct() {

			// Add Hook into the 'init()' action			
			add_action ( 'init', array ( $this, 'dt_init' ) );

			// Add Hook into the 'admin_init()' action
			add_action ( 'admin_init', array ( $this, 'dt_admin_init' ) );

			// Add Hook into the 'template_include' filter
			add_filter ( 'template_include', array ( $this, 'dt_template_include' ) );

			add_action( 'widgets_init', array( $this, 'dt_doctor_register_sidebars' ) , 100 );

			add_filter( 'cs_metabox_options', array( $this, 'dt_doctor_cs_metabox_options') );

			add_filter( 'cs_framework_options', array( $this, 'dt_doctor_cs_framework_options') );
		}

		/**
		 * A function hook that the WordPress core launches at 'init' points
		 * Works in both front and back end
		 */
		function dt_init() {

			$this->createPostType();

		}

		/**
		 * A function hook that the WordPress core launches at 'admin_init' points
		 * Works in back end
		 */
		function dt_admin_init() {
			
			add_filter ( "manage_edit-dt_doctor_columns", array (
				$this,
				"dt_doctors_edit_columns" 
			) );
			
			add_action ( "manage_posts_custom_column", array (
				$this,
				"dt_doctors_columns_display" 
			), 10, 2 );			
		}
		
		function createPostType() {
			
			$portslug 		= 'dt_doctors';
			$taxslug  		= 'doctor_departments';
			$singular_name  = __('Doctor', 'psychiatrist-doctor');
			$plural_name    = __('Doctors', 'psychiatrist-doctor');
			$tax_sname 		= __('Department','psychiatrist-doctor');
			$tax_pname      = __('Departments','psychiatrist-doctor');
			
			if( function_exists( 'psychiatrist_cs_get_option' ) ) :
				$postslug 		=	psychiatrist_cs_get_option( 'single-doctor-slug', 'dt_doctors' );
				$taxslug  		=	psychiatrist_cs_get_option( 'doctor-department-slug', 'doctor_departments' );
				$singular_name  =	psychiatrist_cs_get_option( 'singular-doctor-name', __('Doctor', 'psychiatrist-doctor') );
				$plural_name	=	psychiatrist_cs_get_option( 'plural-doctor-name', __('Doctors', 'psychiatrist-doctor') );
				$tax_sname	  	=	psychiatrist_cs_get_option( 'singular-doctor-tax-name', __('Department', 'psychiatrist-doctor') );
				$tax_pname		=	psychiatrist_cs_get_option( 'plural-doctor-tax-name', __('Departments', 'psychiatrist-doctor') );
			endif;

			$labels = array (
				'name'				  => 	$plural_name,
				'all_items' 		  => 	__ ( 'All ', 'psychiatrist-doctor' ) . $plural_name,
				'singular_name' 	  => 	$singular_name,
				'add_new' 			  => 	__ ( 'Add New', 'psychiatrist-doctor' ),
				'add_new_item' 		  => 	__ ( 'Add New ', 'psychiatrist-doctor' ) . $singular_name,
				'edit_item' 		  => 	__ ( 'Edit ', 'psychiatrist-doctor' ) . $singular_name,
				'new_item' 			  => 	__ ( 'New ', 'psychiatrist-doctor' ) . $singular_name,
				'view_item' 		  => 	__ ( 'View ', 'psychiatrist-doctor' ) . $singular_name,
				'search_items' 		  =>	__ ( 'Search ', 'psychiatrist-doctor' ) . $plural_name,
				'not_found' 		  => 	__ ( 'No ', 'psychiatrist-doctor' ) . $plural_name . __ ( ' found', 'psychiatrist-doctor' ),
				'not_found_in_trash'  => 	__ ( 'No ', 'psychiatrist-doctor' ) . $plural_name . __ ( ' found in Trash', 'psychiatrist-doctor' ),
				'parent_item_colon'   => 	__ ( 'Parent ', 'psychiatrist-doctor' ) . $singular_name . ':',
				'menu_name' 		  => 	$plural_name
			);
			
			$args = array (
				'labels' 			  => $labels,
				'hierarchical' 		  => false,
				'description' 		  => __( 'This is custom post type ', 'psychiatrist-doctor' ) . $plural_name,
				'supports' 			  => array ( 'title', 'editor', 'thumbnail','revisions'),
				'public' 			  => true,
				'show_in_rest' => true,
				'show_ui' 			  => true,
				'show_in_menu' 		  => true,
				'menu_position' 	  => 10,
				'menu_icon' 		  => 'dashicons-admin-users',
				'show_in_nav_menus'   => true,
				'publicly_queryable'  => true,
				'exclude_from_search' => false,
				'has_archive' 		  => true,
				'query_var' 	  	  => true,
				'can_export' 	  	  => true,
				'show_in_rest' => true,
				'rewrite' 		  	  => array( 'slug' => $postslug ),
				'capability_type' 	  => 'post'
			);
			
			register_post_type ( 'dt_doctors', $args );

			$labels = array(
				'name'                => $tax_pname,
				'singular_name'       => $tax_sname,
				'search_items'        => __( 'Search ', 'psychiatrist-doctor' ) . $tax_pname,
				'all_items'           => __( 'All ', 'psychiatrist-doctor' ) . $tax_pname,
				'parent_item'         => __( 'Parent ', 'psychiatrist-doctor' ) . $tax_sname,
				'parent_item_colon'   => __( 'Parent ', 'psychiatrist-doctor' ) . $tax_sname . ':',
				'edit_item'           => __( 'Edit ', 'psychiatrist-doctor' ) . $tax_sname,
				'update_item'         => __( 'Update ', 'psychiatrist-doctor' ) . $tax_sname,
				'add_new_item'        => __( 'Add New ', 'psychiatrist-doctor' ) . $tax_sname,
				'new_item_name'       => __( 'New ', 'psychiatrist-doctor') . $tax_sname . __(' Name', 'psychiatrist-doctor' ),
				'menu_name'           => $tax_pname
			);
			
			register_taxonomy ( 'doctor_departments', array('dt_doctors'), array(
				'hierarchical'      => true,
				'labels'            => $labels,
				'show_ui'           => true,
				'show_admin_column' => true,
				"show_in_rest"      => true,
				'rewrite'           => array( 'slug' => $taxslug ),
				'query_var'         => true 
			));			
		}
		
		function dt_doctor_cs_metabox_options( $options ) {

			$cptitle = psychiatrist_cs_get_option( 'singular-doctor-name', esc_html__('Doctor', 'psychiatrist-doctor') );
			$fields = cs_get_option( 'doctor-custom-fields');
			$bothfields = $fielddef = $x = array();
			$before = '';

			if(!empty($fields)) :

				$i = 1;
				foreach($fields as $field):
					$x['id'] = 'doctor_opt_flds_title_'.$i;
					$x['type'] = 'text';
					$x['title'] = 'Title';
					$x['attributes'] = array( 'style' => 'background-color: #f0eff9;' );
					$bothfields[] = $x;
					unset($x);
			
					$x['id'] = 'doctor_opt_flds_value_'.$i;
					$x['type'] = 'text';
					$x['title'] = 'Value';
					$bothfields[] = $x;

					$fielddef['doctor_opt_flds_title_'.$i] = $field['doctor-custom-fields-text'];

					$i++;
				endforeach;	
			else:
				$before = '<span>'.esc_html__('Go to options panel add few custom fields, then return back here.', 'psychiatrist-doctor').'</span>';
			endif;

			$options[]    = array(
			  'id'        => '_custom_settings',
			  'title'     => "Custom {$cptitle} Options",
			  'post_type' => 'dt_doctors',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(
			
				array(
				  'name'  => 'general_section',
				  'title' => esc_html__('General Options', 'psychiatrist-doctor'),
				  'icon'  => 'fa fa-cogs',
			
				  'fields' => array(
			
					array(
					  'id'    => 'breadcrumb_background',
					  'type'  => 'background',
					  'title' => esc_html__('Background', 'psychiatrist-doctor'),
					  'desc'  => esc_html__('Choose background options for breadcrumb title section.', 'psychiatrist-doctor')
					),
			
					array(
					  'id'      	 => 'layout',
					  'type'         => 'image_select',
					  'title'        => esc_html__('Layout', 'psychiatrist-doctor'),
					  'options'      => array(
						'content-full-width'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
						'with-left-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
						'with-right-sidebar'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
					  ),
					  'default'      => 'content-full-width',
					  'attributes'   => array(
						'data-depend-id' => 'layout',
					  ),
					),
			
					array(
					  'id'  		 => 'show-standard-sidebar-left',
					  'type'  		 => 'switcher',
					  'title' 		 => esc_html__('Show Standard Left Sidebar', 'psychiatrist-doctor'),
					  'dependency'   => array( 'layout', 'any', 'with-left-sidebar' ),
					),
					
					array(
					  'id'  		 => 'widget-area-left',
					  'type'  		 => 'select',
					  'title' 		 => esc_html__('Choose Widget Area - Left Sidebar', 'psychiatrist-doctor'),
					  'class'		 => 'chosen',
					  'options'   	 => psychiatrist_custom_widgets(),
					  'attributes'   => array(
					  	'multiple'  	   => 'multiple',
						'data-placeholder' => esc_attr__('Select Widget Areas', 'psychiatrist-doctor'),
					    'style' 		   => 'width: 400px;'
					  ),
					  'dependency'   => array( 'layout', 'any', 'with-left-sidebar' ),
					),
			
					array(
					  'id'  		 => 'show-standard-sidebar-right',
					  'type'  		 => 'switcher',
					  'title' 		 => esc_html__('Show Standard Right Sidebar', 'psychiatrist-doctor'),
					  'dependency'   => array( 'layout', 'any', 'with-right-sidebar' ),
					),
					
					array(
					  'id'  		 => 'widget-area-right',
					  'type'  		 => 'select',
					  'title' 		 => esc_html__('Choose Widget Area - Right Sidebar', 'psychiatrist-doctor'),
					  'class'		 => 'chosen',
					  'options'   	 => psychiatrist_custom_widgets(),
					  'attributes'   => array(
					  	'multiple'  	   => 'multiple',
						'data-placeholder' => esc_attr__('Select Widget Areas', 'psychiatrist-doctor'),
					    'style' 		   => 'width: 400px;'
					  ),
					  'dependency'   => array( 'layout', 'any', 'with-right-sidebar' ),
					),
			
				  ), // end: fields
				), // end: a section
			
				array(
				  'name'  => 'additional_section',
				  'title' => esc_html__('Additional Fields', 'psychiatrist-doctor'),
				  'icon'  => 'fa fa-list',
			
				  'fields' => array(
			
					array(
					  'id'         => 'prefix',
					  'type'       => 'text',
					  'title'      => esc_html__('Prefix Name', 'psychiatrist-doctor'),
					  'attributes'    => array(
						'placeholder' => esc_attr__('You can given a prefix to the name. eg: Dr.', 'psychiatrist-doctor'),
					  )
					),
			
					array(
					  'id'         => 'postfix',
					  'type'       => 'text',
					  'title'      => esc_html__('Postfix Name', 'psychiatrist-doctor'),
					  'attributes'    => array(
						'placeholder' => esc_attr__('You can given a postfix to the name.', 'psychiatrist-doctor')
					  )
					),
			
					array(
					  'id'         => 'email',
					  'type'       => 'text',
					  'title'      => esc_html__('Email ID', 'psychiatrist-doctor'),
					  'attributes'    => array(
						'placeholder' => esc_attr__('You can given email id.', 'psychiatrist-doctor'),
					  )
					),
			
					array(
					  'id'         => 'telno',
					  'type'       => 'text',
					  'title'      => esc_html__('Tel Number', 'psychiatrist-doctor'),
					  'attributes'    => array(
						'placeholder' => esc_attr__('You can given telephone no.', 'psychiatrist-doctor'),
					  )
					),
			
					array(
					  'id'         => 'summary',
					  'type'       => 'text',
					  'title'      => esc_html__('Summary', 'psychiatrist-doctor'),
					  'attributes' => array(
						'style'    => 'width: 100%;'
					  )
					),
			
					array(
					  'id'       => 'social',
					  'type'     => 'wysiwyg',
					  'title'    => esc_html__('Social Profile', 'psychiatrist-doctor'),
					  'settings' => array(
						'textarea_rows' => 5,
						'tinymce'       => false,
						'media_buttons' => false,
					  ),
					  'info' => esc_html__('You can given social shortcode.', 'psychiatrist-doctor').' eg: [dt_sc_social facebook="#" twitter="#"/]',
					),
			
				  ), // end: fields
				), // end: a section
			
				array(
				  'name'  => 'optional_section',
				  'title' => esc_html__('Optional Fields', 'psychiatrist-doctor'),
				  'icon'  => 'fa fa-plug',
			
				  'fields' => array(
			
					array(
					  'id'        => 'doctor_opt_flds',
					  'type'      => 'fieldset',
					  'title'     => esc_html__('Optional Fields', 'psychiatrist-doctor'),
					  'fields'    => $bothfields,
					  'default'   => $fielddef,
					  'before' 	  => $before
					),
			
				  ), // end: fields
				), // end: a section
			
			  ),
			);
			
			return $options;
		}

		function dt_doctor_cs_framework_options( $options ) {

			$cptitle = psychiatrist_cs_get_option( 'singular-doctor-name', esc_html__('Doctor', 'psychiatrist-doctor') );
			$taxtitle = psychiatrist_cs_get_option( 'singular-doctor-tax-name', esc_html__('Department', 'psychiatrist-doctor') );

			$options[]      = array(
			  'name'        => 'doctors',
			  'title'       => esc_html__('Doctors', 'psychiatrist-doctor'),
			  'icon'        => 'fa fa-medkit',
			
			  'fields'      => array(
			
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( "$taxtitle Archive Page Layout", 'psychiatrist-doctor' ),
				),
			
				array(
				  'id'           => 'doctor-post-style',
				  'type'         => 'select',
				  'title'        => esc_html__('Post Style', 'psychiatrist-doctor'),
				  'options'      => array(
					'1'          => esc_html__('Two Columns - Style 1', 'psychiatrist-doctor'),
					'2'          => esc_html__('Three Columns - Style 1', 'psychiatrist-doctor'),
					'3'          => esc_html__('Two Columns - Style 2', 'psychiatrist-doctor'),
					'4'          => esc_html__('Three Columns - Style 2', 'psychiatrist-doctor'),
					'5'          => esc_html__('Four Columns - Style 2', 'psychiatrist-doctor'),
				  ),
				  'class'        => 'chosen',
				  'default'      => '1',
				  'info'       	 => esc_html__('Choose the doctor post layout style', 'psychiatrist-doctor')
				),
			
				array(
				  'id'      	 => 'doctors-archives-page-layout',
				  'type'         => 'image_select',
				  'title'        => esc_html__('Layout', 'psychiatrist-doctor'),
				  'options'      => array(
					'content-full-width'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
					'with-left-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
					'with-right-sidebar'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
					'with-both-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/both-sidebar.png',
				  ),
				  'default'      => 'content-full-width',
				  'attributes'   => array(
					'data-depend-id' => 'doctors-archives-page-layout',
				  ),
				),
			
				array(
				  'id'  		 => 'show-standard-left-sidebar-for-doctor_departments',
				  'type'  		 => 'switcher',
				  'title' 		 => esc_html__('Show Standard Left Sidebar', 'psychiatrist-doctor'),
				  'dependency'   => array( 'doctors-archives-page-layout', 'any', 'with-left-sidebar,with-both-sidebar' ),
				),
			
				array(
				  'id'  		 => 'show-standard-right-sidebar-for-doctor_departments',
				  'type'  		 => 'switcher',
				  'title' 		 => esc_html__('Show Standard Right Sidebar', 'psychiatrist-doctor'),
				  'dependency'   => array( 'doctors-archives-page-layout', 'any', 'with-right-sidebar,with-both-sidebar' ),
				),
			
				// ----------------------------------------
				// a option sub section for custom fiels  -
				// ----------------------------------------
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( "$cptitle Custom Fields", 'psychiatrist-doctor' ),
				),
			
				array(
				  'id'              => 'doctor-custom-fields',
				  'type'            => 'group',
				  'title'           => esc_html__('Custom Fields', 'psychiatrist-doctor'),
				  'info'            => esc_html__('Click button to add custom fields', 'psychiatrist-doctor'),
				  'button_title'    => esc_html__('Add New Field', 'psychiatrist-doctor'),
				  'accordion_title' => esc_html__('Adding New Custom Field', 'psychiatrist-doctor'),
				  'fields'          => array(
					array(
					  'id'          => 'doctor-custom-fields-text',
					  'type'        => 'text',
					  'title'       => esc_html__('Enter Text', 'psychiatrist-doctor')
					),
				  )
				),
			
				// ----------------------------------------
				// a option sub section for permalinks    -
				// ----------------------------------------
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( 'Permalinks', 'psychiatrist-doctor' ),
				),
			
				array(
				  'id'      => 'single-doctor-slug',
				  'type'    => 'text',
				  'title'   => esc_html__('Single Doctor Slug', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. doctor-item', 'psychiatrist-doctor').' <br> <b>'.esc_html__('After made changes save permalinks.', 'psychiatrist-doctor').'</b></p>',
				),
				
				array(
				  'id'      => 'doctor-department-slug',
				  'type'    => 'text',
				  'title'   => esc_html__('Doctor Department Slug', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. doctor-types', 'psychiatrist-doctor').' <br> <b>'.esc_html__('After made changes save permalinks.', 'psychiatrist-doctor').'</b></p>',
				),
			
				array(
				  'id'      => 'singular-doctor-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Singular Doctor Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Doctor", save options & reload.', 'psychiatrist-doctor').'</p>',
				),
			
				array(
				  'id'      => 'plural-doctor-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Plural Doctor Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Doctors". save options & reload.', 'psychiatrist-doctor').'</p>',
				),
			
				array(
				  'id'      => 'singular-doctor-tax-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Singular Doctor Department Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Department". save options & reload.', 'psychiatrist-doctor').'</p>',
				),
			
				array(
				  'id'      => 'plural-doctor-tax-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Plural Doctor Department Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Departments". save options & reload.', 'psychiatrist-doctor').'</p>',
				),
			
			  ),
			);

			return $options;
		}

		function dt_doctors_edit_columns( $columns ) {
			
			$newcolumns = array (
				"cb" 					=> "<input type=\"checkbox\" />",
				"dt_doctor_thumb" 		=> __("Image", "psychiatrist-doctor"),
				"title" 				=> __("Title", "psychiatrist-doctor"),
				"author" 				=> __("Author", "psychiatrist-doctor")
			);
			$columns = array_merge ( $newcolumns, $columns );
			return $columns;			
		}

		function dt_doctors_columns_display( $columns, $id ) {
			global $post;

			switch ($columns) {
				case "dt_doctor_thumb" :
				
				    $image = wp_get_attachment_image(get_post_thumbnail_id($id), array(75,75));
					if(!empty($image)):
					  	echo $image;
					endif;
				break;
			}			
		}

		/**
		 * To load doctor pages in front end
		 *
		 * @param string $template        	
		 * @return string
		 */
		function dt_template_include($template) {
			if (is_singular( 'dt_doctors' )) {
				if (! file_exists ( get_stylesheet_directory () . '/single-dt_doctors.php' )) {
					$template = plugin_dir_path ( __FILE__ ) . 'templates/single-dt_doctors.php';
				}
			} elseif (is_tax ( 'doctor_departments' )) {
				if (! file_exists ( get_stylesheet_directory () . '/taxonomy-doctor_departments.php' )) {
					$template = plugin_dir_path ( __FILE__ ) . 'templates/taxonomy-doctor_departments.php';
				}
			}
			return $template;
		}

		function dt_doctor_register_sidebars() {

			$layout = "";
			$layout = cs_get_option('doctors-archives-page-layout');

			$layout = !empty($layout) ? $layout : "content-full-width";
			$wtstyle = cs_get_option( 'wtitle-style' );

			$before_title = '<h3 class="widgettitle">';
			$after_title = '</h3>';
		
			if( $wtstyle == 'type17' ):
				$before_title = ' <div class="mz-title"> <div class="mz-title-content"> <h3 class="widgettitle">';
				$after_title  = '</h3> </div> </div>';
			elseif( $wtstyle == 'type18' ):
				$before_title = ' <div class="mz-stripe-title"> <div class="mz-stripe-title-content"> <h3 class="widgettitle">';
				$after_title  = '</h3> </div> </div>';
			endif;
			
			switch($layout) :
				case 'with-left-sidebar':
					register_sidebar(array(
						'name' 			=>	esc_html__("Doctors Archive | Left Sidebar",'psychiatrist-doctor'),
						'id'			=>	'doctor_departments-archives-sidebar-left',
						'description'   =>  esc_html__("Appears in the Left side of Doctors Archive Page.","psychiatrist-doctor"),
						'before_widget' => 	'<aside id="%1$s" class="widget %2$s">',
						'after_widget' 	=> 	'</aside>',
						'before_title' 	=> 	$before_title,
						'after_title' 	=> 	$after_title));
				break;

				case 'with-right-sidebar':
					register_sidebar(array(
						'name' 			=>	esc_html__("Doctors Archive | Right Sidebar",'psychiatrist-doctor'),
						'id'			=>	'doctor_departments-archives-sidebar-right',
						'description'   =>  esc_html__("Appears in the Right side of Doctors Archive Page.","psychiatrist-doctor"),
						'before_widget' => 	'<aside id="%1$s" class="widget %2$s">',
						'after_widget' 	=> 	'</aside>',
						'before_title' 	=> 	$before_title,
						'after_title' 	=> 	$after_title));
				break;

				case 'with-both-sidebar':
					register_sidebar(array(
						'name' 			=>	esc_html__("Doctors Archive | Left Sidebar",'psychiatrist-doctor'),
						'id'			=>	'doctor_departments-archives-sidebar-left',
						'description'   =>  esc_html__("Appears in the Left side of Doctors Archive Page.","psychiatrist-doctor"),
						'before_widget' => 	'<aside id="%1$s" class="widget %2$s">',
						'after_widget' 	=> 	'</aside>',
						'before_title' 	=> 	$before_title,
						'after_title' 	=> 	$after_title));

					register_sidebar(array(
						'name' 			=>	esc_html__("Doctors Archive | Right Sidebar",'psychiatrist-doctor'),
						'id'			=>	'doctor_departments-archives-sidebar-right',
						'description'   =>  esc_html__("Appears in the Right side of Doctors Archive Page.","psychiatrist-doctor"),
						'before_widget' => 	'<aside id="%1$s" class="widget %2$s">',
						'after_widget' 	=> 	'</aside>',
						'before_title' 	=> 	$before_title,
						'after_title' 	=> 	$after_title));
				break;
			endswitch;
		}
	}
}?>