<?php
if (! class_exists ( 'DTProcedurePostType' )) {
	class DTProcedurePostType {

		/**
		 * A function constructor calls initially
		 */
		function __construct() {

			// Add Hook into the 'init()' action
			add_action ( 'init', array (
				$this,
				'dt_init'
			) );

			// Add Hook into the 'admin_init()' action
			add_action ( 'admin_init', array (
				$this,
				'dt_admin_init'
			) );

			// Add Hook into the 'template_include' filter
			add_filter ( 'template_include', array (
				$this,
				'dt_template_include'
			) );

			add_filter ( 'cs_metabox_options', array (
				$this,
				'dt_procedure_cs_metabox_options'
			) );

			add_filter ( 'cs_framework_options', array (
				$this,
				'dt_procedure_cs_framework_options'
			) );
		}

		/**
		 * A function hook that the WordPress core launches at 'init' points
		 */
		function dt_init() {
			$this->createPostType ();
		}

		/**
		 * A function hook that the WordPress core launches at 'admin_init' points
		 */
		function dt_admin_init() {
			
			add_filter ( "manage_edit-dt_procedure_columns", array (
				$this,
				"dt_procedure_edit_columns" 
			) );
			
			add_action ( "manage_posts_custom_column", array (
				$this,
				"dt_procedure_columns_display" 
			), 10, 2 );
		}

		/**
		 */
		function createPostType() {
			$postslug	 	= 'dt_procedure';							$taxslug  = 'procedure_entries';
			$singular_name  = __('Procedure', 'psychiatrist-doctor'); 	$plural_name  = __('Procedures', 'psychiatrist-doctor');
			$tax_sname 		= __( 'Category','psychiatrist-doctor' );	$tax_pname    = __( 'Categories','psychiatrist-doctor' );

			if( function_exists( 'psychiatrist_cs_get_option' ) ) :
				$postslug 		=	psychiatrist_cs_get_option( 'single-procedure-slug', 'dt_procedure' );
				$taxslug  		=	psychiatrist_cs_get_option( 'procedure-category-slug', 'procedure_entries' );
				$singular_name  =	psychiatrist_cs_get_option( 'singular-procedure-name', __('Procedure', 'psychiatrist-doctor') );
				$plural_name	=	psychiatrist_cs_get_option( 'plural-procedure-name', __('Procedures', 'psychiatrist-doctor') );
				$tax_sname	  	=	psychiatrist_cs_get_option( 'singular-procedure-tax-name', __('Category', 'psychiatrist-doctor') );
				$tax_pname		=	psychiatrist_cs_get_option( 'plural-procedure-tax-name', __('Categories', 'psychiatrist-doctor') );
			endif;

			$labels = array (
					'name'				=> 	$plural_name,
					'all_items' 		=> 	__ ( 'All ', 'psychiatrist-doctor' ) . $plural_name,
					'singular_name' 	=> 	$singular_name,
					'add_new' 			=> 	__ ( 'Add New', 'psychiatrist-doctor' ),
					'add_new_item' 		=> 	__ ( 'Add New ', 'psychiatrist-doctor' ) . $singular_name,
					'edit_item' 		=> 	__ ( 'Edit ', 'psychiatrist-doctor' ) . $singular_name,
					'new_item' 			=> 	__ ( 'New ', 'psychiatrist-doctor' ) . $singular_name,
					'view_item' 		=> 	__ ( 'View ', 'psychiatrist-doctor' ) . $singular_name,
					'search_items' 		=>	__ ( 'Search ', 'psychiatrist-doctor' ) . $plural_name,
					'not_found' 		=> 	__ ( 'No ', 'psychiatrist-doctor' ) . $plural_name . __ ( ' found', 'psychiatrist-doctor' ),
					'not_found_in_trash' => __ ( 'No ', 'psychiatrist-doctor' ) . $plural_name . __ ( ' found in Trash', 'psychiatrist-doctor' ),
					'parent_item_colon' => 	__ ( 'Parent ', 'psychiatrist-doctor' ) . $singular_name . ':',
					'menu_name' 		=> 	$plural_name
			);

			$args = array (
					'labels' => $labels,
					'hierarchical' => false,
					'description' => __( 'This is custom post type ', 'psychiatrist-doctor' ) . $plural_name,
					'supports' => array (
						'title',
						'editor',
						'excerpt',
						'thumbnail',
						'revisions'
					),

					'public' => true,
					'show_in_rest' => true,
					'show_ui' => true,
					'show_in_menu' => true,
					'menu_position' => 10,
					'menu_icon' => 'dashicons-portfolio',
					
					'show_in_nav_menus' => true,
					'publicly_queryable' => true,
					'exclude_from_search' => false,
					'has_archive' => true,
					'query_var' => true,
					'can_export' => true,
					'rewrite' => array( 'slug' => $postslug ),
					'capability_type' => 'post'
			);

			register_post_type ( 'dt_procedure', $args );

			$labels = array(
				'name'              => 	$tax_pname,
				'singular_name'     => 	$tax_sname,
				'search_items'      => 	__( 'Search ', 'designthemes-procedure' ) . $tax_pname,
				'all_items'         => 	__( 'All ', 'designthemes-procedure' ) . $tax_pname,
				'parent_item'       => 	__( 'Parent ', 'designthemes-procedure' ) . $tax_sname,
				'parent_item_colon' => 	__( 'Parent ', 'designthemes-procedure' ) . $tax_sname . ':',
				'edit_item'         => 	__( 'Edit ', 'designthemes-procedure' ) . $tax_sname,
				'update_item'       => 	__( 'Update ', 'designthemes-procedure' ) . $tax_sname,
				'add_new_item'      => 	__( 'Add New ', 'designthemes-procedure' ) . $tax_sname,
				'new_item_name'     => 	__( 'New ', 'designthemes-procedure') . $tax_sname . __(' Name', 'designthemes-procedure' ),
				'menu_name'         => 	$tax_pname
			);

			register_taxonomy ( 'procedure_entries', array (
				'dt_procedure' 
			), array (
				'hierarchical' 		=> 	true,
				'labels' 			=> 	$labels,
				'show_ui'           => 	true,
				'show_admin_column' => 	true,
				"show_in_rest"      => true,
				'rewrite' 			=> 	array( 'slug' => $taxslug ),
				'query_var' 		=> 	true 
			) );
		}

		function dt_procedure_cs_metabox_options( $options ) {

			$cptitle = psychiatrist_cs_get_option( 'singular-procedure-name', esc_html__('Procedure', 'psychiatrist-doctor') );
			$fields = cs_get_option( 'procedure-custom-fields');
			$bothfields = $fielddef = $x = array();
			$before = '';

			if(!empty($fields)) :

				$i = 1;
				foreach($fields as $field):
					$x['id'] = 'procedure_opt_flds_title_'.$i;
					$x['type'] = 'text';
					$x['title'] = 'Title';
					$x['attributes'] = array( 'style' => 'background-color: #f0eff9;' );
					$bothfields[] = $x;
					unset($x);
			
					$x['id'] = 'procedure_opt_flds_value_'.$i;
					$x['type'] = 'text';
					$x['title'] = 'Value';
					$bothfields[] = $x;
			
					$fielddef['procedure_opt_flds_title_'.$i] = $field['procedure-custom-fields-text'];
			
					$i++;
				endforeach;
			else:
				$before = '<span>'.esc_html__('Go to options panel add few custom fields, then return back here.', 'psychiatrist-doctor').'</span>';
			endif;
			
			$options[]    = array(
			  'id'        => '_custom_settings',
			  'title'     => "Custom {$cptitle} Options",
			  'post_type' => 'dt_procedure',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(
			
				array(
				  'name'  => 'general_section',
				  'title' => esc_html__('General Options', 'psychiatrist-doctor'),
				  'icon'  => 'fa fa-cogs',
			
				  'fields' => array(
			
					array(
					  'id'    => 'breadcrumb_background',
					  'type'  => 'background',
					  'title' => esc_html__('Background', 'psychiatrist-doctor'),
					  'desc'  => esc_html__('Choose background options for breadcrumb title section.', 'psychiatrist-doctor'),
					),
			
					array(
					  'id'      	 => 'layout',
					  'type'         => 'image_select',
					  'title'        => esc_html__('Layout', 'psychiatrist-doctor'),
					  'options'      => array(
						'content-full-width'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
						'with-left-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
						'with-right-sidebar'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
					  ),
					  'default'      => 'content-full-width',
					  'attributes'   => array(
						'data-depend-id' => 'layout',
					  ),
					),

					array(
					  'id'  		 => 'show-standard-sidebar-left',
					  'type'  		 => 'switcher',
					  'title' 		 => esc_html__('Show Standard Left Sidebar', 'psychiatrist-doctor'),
					  'dependency'   => array( 'layout', 'any', 'with-left-sidebar' ),
					),

					array(
					  'id'  		 => 'widget-area-left',
					  'type'  		 => 'select',
					  'title' 		 => esc_html__('Choose Widget Area - Left Sidebar', 'psychiatrist-doctor'),
					  'class'		 => 'chosen',
					  'options'   	 => psychiatrist_custom_widgets(),
					  'attributes'   => array(
					  	'multiple'  	   => 'multiple',
						'data-placeholder' => esc_attr__('Select Widget Areas', 'psychiatrist-doctor'),
					    'style' 		   => 'width: 400px;'
					  ),
					  'dependency'   => array( 'layout', 'any', 'with-left-sidebar' ),
					),

					array(
					  'id'  		 => 'show-standard-sidebar-right',
					  'type'  		 => 'switcher',
					  'title' 		 => esc_html__('Show Standard Right Sidebar', 'psychiatrist-doctor'),
					  'dependency'   => array( 'layout', 'any', 'with-right-sidebar' ),
					),

					array(
					  'id'  		 => 'widget-area-right',
					  'type'  		 => 'select',
					  'title' 		 => esc_html__('Choose Widget Area - Right Sidebar', 'psychiatrist-doctor'),
					  'class'		 => 'chosen',
					  'options'   	 => psychiatrist_custom_widgets(),
					  'attributes'   => array(
					  	'multiple'  	   => 'multiple',
						'data-placeholder' => esc_attr__('Select Widget Areas', 'psychiatrist-doctor'),
					    'style' 		   => 'width: 400px;'
					  ),
					  'dependency'   => array( 'layout', 'any', 'with-right-sidebar' ),
					),

					array(
					  'id'         => 'price',
					  'type'       => 'text',
					  'title'      => esc_html__('Price', 'psychiatrist-doctor'),
					  'info' 	   => esc_attr__('You can given procedure price here. eg: Starts From $250', 'psychiatrist-doctor'),
					),

				  ), // end: fields
				), // end: a section

				array(
				  'name'  => 'optional_section',
				  'title' => esc_html__('Optional Fields', 'psychiatrist-doctor'),
				  'icon'  => 'fa fa-plug',
			
				  'fields' => array(
			
					array(
					  'id'        => 'procedure_opt_flds',
					  'type'      => 'fieldset',
					  'title'     => esc_html__('Optional Fields', 'psychiatrist-doctor'),
					  'fields'    => $bothfields,
					  'default'   => $fielddef,
					  'before' 	  => $before
					),
			
				  ), // end: fields
				), // end: a section
			
			  ),
			);

			return $options;
		}

		function dt_procedure_cs_framework_options( $options ) {

			$cptitle = psychiatrist_cs_get_option( 'singular-procedure-name', esc_html__('Procedure', 'psychiatrist-doctor') );

			$options[]      = array(
			  'name'        => 'procedures',
			  'title'       => esc_html__('Procedures', 'psychiatrist-doctor'),
			  'icon'        => 'fa fa-cubes',

			  'fields'      => array(

				// -----------------------------------
				// a option sub section for layouts  -
				// -----------------------------------
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( "$cptitle Category Archives Page Layout", 'psychiatrist-doctor' ),
				),

				array(
				  'id'      	 => 'procedure-archives-page-layout',
				  'type'         => 'image_select',
				  'title'        => esc_html__('Layout', 'psychiatrist-doctor'),
				  'options'      => array(
					'content-full-width'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
					'with-left-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
					'with-right-sidebar'   => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
					'with-both-sidebar'    => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/both-sidebar.png',
				  ),
				  'default'      => 'content-full-width',
				  'attributes'   => array(
					'data-depend-id' => 'procedure-archives-page-layout',
				  ),
				),

				array(
				  'id'  		 => 'show-standard-left-sidebar-for-procedure_entries',
				  'type'  		 => 'switcher',
				  'title' 		 => esc_html__('Show Standard Left Sidebar', 'psychiatrist-doctor'),
				  'dependency'   => array( 'procedure-archives-page-layout', 'any', 'with-left-sidebar,with-both-sidebar' ),
				),

				array(
				  'id'  		 => 'show-standard-right-sidebar-for-procedure_entries',
				  'type'  		 => 'switcher',
				  'title' 		 => esc_html__('Show Standard Right Sidebar', 'psychiatrist-doctor'),
				  'dependency'   => array( 'procedure-archives-page-layout', 'any', 'with-right-sidebar,with-both-sidebar' ),
				),

				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( "$cptitle Category Archives Post Layout", 'psychiatrist-doctor' ),
				),

				array(
				  'id'      	 => 'procedure-archives-post-layout',
				  'type'         => 'image_select',
				  'title'        => esc_html__('Post Layout', 'psychiatrist-doctor'),
				  'options'      => array(
					'one-third-column'  => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/one-third-column.png',
					'one-fourth-column' => PSYCHIATRIST_THEME_URI . '/cs-framework-override/images/one-fourth-column.png',
				  ),
				  'default'      => 'one-third-column',
				),

				// ----------------------------------------
				// a option sub section for custom fiels  -
				// ----------------------------------------
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( "$cptitle Custom Fields", 'psychiatrist-doctor' ),
				),
			
				array(
				  'id'              => 'procedure-custom-fields',
				  'type'            => 'group',
				  'title'           => esc_html__('Custom Fields', 'psychiatrist-doctor'),
				  'info'            => esc_html__('Click button to add custom fields', 'psychiatrist-doctor'),
				  'button_title'    => esc_html__('Add New Field', 'psychiatrist-doctor'),
				  'accordion_title' => esc_html__('Adding New Custom Field', 'psychiatrist-doctor'),
				  'fields'          => array(
					array(
					  'id'          => 'procedure-custom-fields-text',
					  'type'        => 'text',
					  'title'       => esc_html__('Enter Text', 'psychiatrist-doctor'),
					),
				  )
				),
				
				// ----------------------------------------
				// a option sub section for permalinks    -
				// ----------------------------------------
				array(
				  'type'    => 'subheading',
				  'content' => esc_html__( 'Permalinks', 'psychiatrist-doctor' ),
				),

				array(
				  'id'      => 'single-procedure-slug',
				  'type'    => 'text',
				  'title'   => esc_html__('Single Procedure slug', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. procedure-item ', 'psychiatrist-doctor').'<br> <b>'.esc_html__('After made changes save permalinks.', 'psychiatrist-doctor').'</b></p>',
				),

				array(
				  'id'      => 'procedure-category-slug',
				  'type'    => 'text',
				  'title'   => esc_html__('Procedure Category slug', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. procedure-types ', 'psychiatrist-doctor').' <br> <b>'.esc_html__('After made changes save permalinks.', 'psychiatrist-doctor').'</b></p>',
				),

				array(
				  'id'      => 'singular-procedure-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Singular Procedure Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Procedure", save options & reload.', 'psychiatrist-doctor').'</p>',
				),

				array(
				  'id'      => 'plural-procedure-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Plural Procedure Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Procedures". save options & reload.', 'psychiatrist-doctor').'</p>',
				),

				array(
				  'id'      => 'singular-procedure-tax-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Singular Procedure Category Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Category". save options & reload.', 'psychiatrist-doctor').'</p>',
				),

				array(
				  'id'      => 'plural-procedure-tax-name',
				  'type'    => 'text',
				  'title'   => esc_html__('Plural Procedure Category Name', 'psychiatrist-doctor'),
				  'after' 	=> '<p class="cs-text-info">'.esc_html__('By default "Categories". save options & reload.', 'psychiatrist-doctor').'</p>',
				),

			  ),
			);

			return $options;
		}

		/**
		 *
		 * @param unknown $columns        	
		 * @return multitype:
		 */
		function dt_procedure_edit_columns($columns) {
			
			$newcolumns = array (
				"cb" => "<input type=\"checkbox\" />",
				"dt_procedure_thumb" => __("Image", "psychiatrist-doctor"),
				"title" => __("Title", "psychiatrist-doctor"),
				"author" => __("Author", "psychiatrist-doctor")
			);
			$columns = array_merge ( $newcolumns, $columns );
			return $columns;
		}
		
		/**
		 *
		 * @param unknown $columns
		 * @param unknown $id
		 */
		function dt_procedure_columns_display($columns, $id) {
			global $post;
			
			switch ($columns) {

				case "dt_procedure_thumb" :
				    $image = wp_get_attachment_image(get_post_thumbnail_id($id), array(75,75));
					if(!empty($image)):
					  	echo !empty($image) ? $image : '';
					endif;
				break;
			}
		}

		/**
		 * To load procedure pages in front end
		 *
		 * @param string $template        	
		 * @return string
		 */
		function dt_template_include($template) {
			if (is_singular( 'dt_procedure' )) {
				if (! file_exists ( get_stylesheet_directory () . '/single-dt_procedure.php' )) {
					$template = plugin_dir_path ( __FILE__ ) . 'templates/single-dt_procedure.php';
				}
			} elseif (is_tax ( 'procedure_entries' )) {
				if (! file_exists ( get_stylesheet_directory () . '/taxonomy-procedure_entries.php' )) {
					$template = plugin_dir_path ( __FILE__ ) . 'templates/taxonomy-procedure_entries.php';
				}
			}
			return $template;
		}
	}
}
?>