<?php
if ( !class_exists( 'DTServicePostType' ) ) {

	class DTServicePostType {
		function __construct() {
			add_action ( 'init', array (
				$this,
				'dt_init'
			) );

			add_action( 'admin_init', array(
				$this,
				'dt_admin_init'
			) );

			add_filter ( "cs_metabox_options", array(
				$this,
				"dt_services_cs_metabox_options"
			) );
		}

		function dt_init() {
			$labels = array(
				'name' => __('Services', 'dtthemes-core' ),
				'singular_name' => __('Service', 'dtthemes-core' ),
				'menu_name' => __('Services', 'dtthemes-core' ),
				'add_new' => __('Add Service', 'dtthemes-core' ),
				'add_new_item' => __('Add New Service', 'dtthemes-core' ),
				'edit' => __('Edit Service', 'dtthemes-core' ),
				'edit_item' => __('Edit Service', 'dtthemes-core' ),
				'new_item' => __('New Service', 'dtthemes-core' ),
				'view' => __('View Service', 'dtthemes-core' ),
				'view_item' => __('View Service', 'dtthemes-core' ),
				'search_items' => __('Search Services', 'dtthemes-core' ),
				'not_found' => __('No Services found', 'dtthemes-core' ),
				'not_found_in_trash' => __('No Services found in Trash', 'dtthemes-core' ),
				'parent_item_colon' => __('Parent Service:', 'dtthemes-core' ),
			);

			$args = array(
				'labels' => $labels,
				'hierarchical' => false,
				'description' => __('This is Custom Post type named as Services','dtthemes-core'),
				'supports' => array('title', 'editor', 'thumbnail','revisions'),
				'public' => true,
				'show_ui' => true,
				'show_in_rest' => true,
				'show_in_menu' => true,
				'menu_position' => 20,
				'menu_icon' => 'dashicons-awards',
			);

			register_post_type('dt_services', $args );
		}

		function dt_admin_init() {

			add_filter ( "manage_edit-dt_services_columns", array(
				$this,
				"dt_services_edit_columns"
			) );

			add_action ( "manage_posts_custom_column", array (
				$this,
				"dt_services_columns_display" 
			), 10, 2 );

		}

		function dt_services_cs_metabox_options( $options ) {

			$times = array();
			for ( $i = 0; $i < 12; $i++ ) :
				for ( $j = 15; $j <= 60; $j += 15 ) :
					$duration = ( $i * 3600 ) + ( $j * 60 );
					$duration_output = psychiatrist_durToString( $duration );
					$times[$duration] = $duration_output;
				endfor;
			endfor;
			
			$options[]    = array(
			  'id'        => '_info',
			  'title'     => "Custom Service Options",
			  'post_type' => 'dt_services',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(
			
				array(
				  'name'  => 'general_section',
			
				  'fields' => array(
			
					array(
					  'id'    => 'price',
					  'type'  => 'text',
					  'title' => 'Price',
					  'attributes' => array( 
						'style' => 'width: 100px;',
						'placeholder' => '150.00'
					  ),
					  'after' => '<b> '.psychiatrist_currency_symbol( cs_get_option( 'appointment-currency' ) ).'</b>',
					),
			
					array(
					  'id'                 => 'duration',
					  'type'               => 'select',
					  'title'              => 'Duration',
					  'options'            => $times,
					  'class'              => 'chosen',
					  'default_option'     => 'Select',
					),
			
				  ), // end: fields
				), // end: a section
			
			  ),
			);

			return $options;
		}

		function dt_services_edit_columns( $columns ) {

			$newcolumns = array (
					"cb" => "<input type=\"checkbox\" />",
					"title" => __("Title",'dtthemes-core'),
					"details" => __("Details",'dtthemes-core'),
					"author" => __("Author",'dtthemes-core'),
			);
			$columns = array_merge ( $newcolumns, $columns );
			return $columns;
		}

		function dt_services_columns_display( $columns, $id ) {
			global $post;
			switch ($columns) {
				case 'details':
					$info = get_post_meta( $post->ID, "_info", true );
					$info = is_array( $info ) ? $info : array();
					$price = array_key_exists('price', $info) ? $info['price'] : "";
					$price = !empty( $price ) ? psychiatrist_currency_symbol( cs_get_option( 'appointment-currency' ) ).' '.$price : "";
					$price = !empty( $price ) ? '<p>'. __("Price","dtthemes-core").' - '.$price .'</p>': ""; 
					echo $price;

					$duration = array_key_exists('duration', $info) ? $info['duration'] : "";
					$duration = !empty($duration) ?'<p>'. __("Duration",'dtthemes-core').' - '.psychiatrist_durToString($duration).'</p>' : "";
					echo $duration;
				break;
			}
		}
	}
}?>
