<?php
if ( !class_exists( 'DTStaffPostType' ) ) {

	class DTStaffPostType {

		function __construct() {
			add_action ( 'init', array (
				$this,
				'dt_init'
			) );

			add_filter ( 'cs_metabox_options', array(
				$this,
				'dt_staffs_cs_metabox_options'
			) );

			add_filter ( 'cs_framework_options', array(
				$this,
				'dt_staffs_cs_framework_options'
			) );
		}

		function dt_init() {
			$labels = array(
				'name' => __('Staffs', 'dtthemes-core' ),
				'singular_name' => __('Staff', 'dtthemes-core' ),
				'menu_name' => __('Staffs', 'dtthemes-core' ),
				'add_new' => __('Add Staff', 'dtthemes-core' ),
				'add_new_item' => __('Add New Staff', 'dtthemes-core' ),
				'edit' => __('Edit Staff', 'dtthemes-core' ),
				'edit_item' => __('Edit Staff', 'dtthemes-core' ),
				'new_item' => __('New Staff', 'dtthemes-core' ),
				'view' => __('View Staff', 'dtthemes-core' ),
				'view_item' => __('View Staff', 'dtthemes-core' ),
				'search_items' => __('Search Staffs', 'dtthemes-core' ),
				'not_found' => __('No Staffs found', 'dtthemes-core' ),
				'not_found_in_trash' => __('No Staffs found in Trash', 'dtthemes-core' ),
				'parent_item_colon' => __('Parent Staff:', 'dtthemes-core' ),
			);

			$args = array(
				'labels' => $labels,
				'hierarchical' => false,
				'description' => __('This is Custom Post type named as Staffs','dtthemes-core'),
				'supports' => array('title', 'editor', 'thumbnail','revisions'),
				'public' => true,
				'show_ui' => true,
				'show_in_menu' => true,
				'menu_position' => 20,
				'show_in_rest' => true,
				'menu_icon' => 'dashicons-businessman',
			);

			register_post_type('dt_staffs', $args );
		}

		function dt_staffs_cs_metabox_options( $options ) {
			
			global $timearray;

			$monday = cs_get_option('appointment_fs1');
			$tuesday = cs_get_option('appointment_fs2');
			$wednesday = cs_get_option('appointment_fs3');
			$thursday = cs_get_option('appointment_fs4');
			$friday = cs_get_option('appointment_fs5');
			$saturday = cs_get_option('appointment_fs6');
			$sunday = cs_get_option('appointment_fs7');
			
			$options[]    = array(
			  'id'        => '_staff_info',
			  'title'     => "Custom Staff Options",
			  'post_type' => 'dt_staffs',
			  'context'   => 'normal',
			  'priority'  => 'default',
			  'sections'  => array(
			
				array(
				  'name'  => 'general_section',
				  'title' => 'General Options',
				  'icon'  => 'fa fa-cogs',
			
				  'fields' => array(
			
					array(
					  'id'    => 'price',
					  'type'  => 'text',
					  'title' => 'Price',
					  'attributes' => array( 
						'style' => 'width: 100px;',
						'placeholder' => '150.00'
					  ),
					  'after' => '<b> '.psychiatrist_currency_symbol( cs_get_option( 'appointment-currency' ) ).'</b>',
					),
			
					array(
					  'id'    => 'emailid',
					  'type'  => 'text',
					  'title' => 'Email Id',
					  'attributes' => array( 
						'placeholder' => 'testmail@domain.com'
					  )
					),
			
				  ), // end: fields
				), // end: a section
			
				array(
				  'name'  => 'schedule_section',
				  'title' => 'Schedule Options',
				  'icon'  => 'fa fa-calendar',
			
				  'fields' => array(
			
					array(
					  'id'        => 'appointment_fs1',
					  'type'      => 'fieldset',
					  'title'     => 'Monday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_monday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_monday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
					  ),
					  'default'   => array(
						'dt_company_monday_start'  => isset($monday['dt_company_monday_start']) && !empty($monday['dt_company_monday_start']) ? $monday['dt_company_monday_start'] : '',
						'dt_company_monday_end'    => isset($monday['dt_company_monday_end']) && !empty($monday['dt_company_monday_end']) ? $monday['dt_company_monday_end'] : '',
					  )
					),
			
					array(
					  'id'        => 'appointment_fs2',
					  'type'      => 'fieldset',
					  'title'     => 'Tuesday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_tuesday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_tuesday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
					  ),
					  'default'   => array(
						'dt_company_tuesday_start'  => isset($tuesday['dt_company_tuesday_start']) && !empty($tuesday['dt_company_tuesday_start']) ? $tuesday['dt_company_tuesday_start'] : '',
						'dt_company_tuesday_end'    => isset($tuesday['dt_company_tuesday_end']) && ! empty($tuesday['dt_company_tuesday_end']) ? $tuesday['dt_company_tuesday_end'] : '',
					  )
					),		
			
					array(
					  'id'        => 'appointment_fs3',
					  'type'      => 'fieldset',
					  'title'     => 'Wednesday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_wednesday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_wednesday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
					  ),
					  'default'   => array(
						'dt_company_wednesday_start'  => isset($wednesday['dt_company_wednesday_start']) && !empty($wednesday['dt_company_wednesday_start']) ? $wednesday['dt_company_wednesday_start'] : '',
						'dt_company_wednesday_end'    => isset($wednesday['dt_company_wednesday_end']) && !empty($wednesday['dt_company_wednesday_end']) ? $wednesday['dt_company_wednesday_end'] : '',
					  )
					),
			
					array(
					  'id'        => 'appointment_fs4',
					  'type'      => 'fieldset',
					  'title'     => 'Thursday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_thursday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_thursday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
					  ),
					  'default'   => array(
						'dt_company_thursday_start'  => isset($thursday['dt_company_thursday_start']) && !empty($thursday['dt_company_thursday_start']) ? $thursday['dt_company_thursday_start'] : '',
						'dt_company_thursday_end'    => isset($thursday['dt_company_thursday_end']) && !empty($thursday['dt_company_thursday_end']) ? $thursday['dt_company_thursday_end'] : '',
					  )
					),
			
					array(
					  'id'        => 'appointment_fs5',
					  'type'      => 'fieldset',
					  'title'     => 'Friday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_friday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_friday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
					  ),
					  'default'   => array(
						'dt_company_friday_start'  => isset($friday['dt_company_friday_start']) && !empty($friday['dt_company_friday_start']) ? $friday['dt_company_friday_start'] : '',
						'dt_company_friday_end'    => isset($friday['dt_company_friday_end']) && !empty($friday['dt_company_friday_end']) ? $friday['dt_company_friday_end'] : '',
					  )
					),
			
					array(
					  'id'        => 'appointment_fs6',
					  'type'      => 'fieldset',
					  'title'     => 'Saturday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_saturday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_saturday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
					  ),
					  'default'   => array(
						'dt_company_saturday_start'  => isset($saturday['dt_company_saturday_start']) && !empty($saturday['dt_company_saturday_start']) ? $saturday['dt_company_saturday_start'] : '',
						'dt_company_saturday_end'    => isset($saturday['dt_company_saturday_end']) && !empty($saturday['dt_company_saturday_end']) ? $saturday['dt_company_saturday_end'] : '',
					  )
					),
			
					array(
					  'id'        => 'appointment_fs7',
					  'type'      => 'fieldset',
					  'title'     => 'Sunday',
					  'fields'    => array(
			
						array(
						  'id'    => 'dt_company_sunday_start',
						  'type'  => 'select',
						  'title'        => 'From:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
			
						array(
						  'id'    => 'dt_company_sunday_end',
						  'type'  => 'select',
						  'title'        => 'To:',
						  'options'      => $timearray,
						  'class'        => 'chosen',
						),
					  ),
					  'default'   => array(
						'dt_company_sunday_start'  => isset($sunday['dt_company_sunday_start'])  && !empty($sunday['dt_company_sunday_start']) ? $sunday['dt_company_sunday_start'] : '',
						'dt_company_sunday_end'    => isset($sunday['dt_company_sunday_end']) && !empty($sunday['dt_company_sunday_end']) ? $sunday['dt_company_sunday_end'] : '',
					  )
					),		
			
				  ), // end: fields
				), // end: a section

			  ),
			);

			// --------------------------------------
			// Staff Metabox Options II             -
			// --------------------------------------
			$cp_services = get_posts( array( 'post_type' => 'dt_services', 'posts_per_page'=> '-1' ) );
			$servicesarr = array();
			
			if ( $cp_services ) {
				foreach ( $cp_services as $cp_service ) {
					$id = $cp_service->ID;
					$title = $cp_service->post_title;
			
					$info = get_post_meta( $id, '_info', true );
					$info = is_array( $info ) ? $info : array();
					$currency = psychiatrist_currency_symbol( cs_get_option( 'appointment-currency' ) );
			
					$price = array_key_exists( 'price', $info ) ? " ( {$currency} ".$info['price'] .' )' : '';
			
					$servicesarr[$id] = $title.$price;
				}
			}
			
			$options[]    = array(
			  'id'        => '_services',
			  'title'     => "Choose Services",
			  'post_type' => 'dt_staffs',
			  'context'   => 'side',
			  'priority'  => 'default',
			  'sections'  => array(
			
				array(
				  'name'  => 'services_section',
			
				  'fields' => array(
			
					array(
					  'id'          => '_services',
					  'type'        => 'checkbox',
					  'options'     => $servicesarr,
					),
			
				  ), // end: fields
				), // end: a section
			
			  ),
			);

			return $options;
		}

		function dt_staffs_cs_framework_options( $options ) {

			global $timearray;
			$timearray = array( '' => 'OFF', '00:00' => '12:00 am', '00:15' => '12:15 am', '00:30' => '12:30 am', '00:45' => '12:45 am', '01:00' => '1:00 am', '01:15' => '1:15 am',
						   '01:30' => '1:30 am', '01:45' => '1:45 am', '02:00' => '2:00 am', '02:15' => '2:15 am', '02:30' => '2:30 am', '02:45' => '2:45 am', '03:00' => '3:00 am',
						   '03:15' => '3:15 am', '03:30' => '3:30 am', '03:45' => '3:45 am', '04:00' => '4:00 am', '04:15' => '4:15 am', '04:30' => '4:30 am', '04:45' => '4:45 am',
						   '05:00' => '5:00 am', '05:15' => '5:15 am', '05:30' => '5:30 am', '05:45' => '5:45 am', '06:00' => '6:00 am', '06:15' => '6:15 am', '06:30' => '6:30 am',
						   '06:45' => '6:45 am', '07:00' => '7:00 am', '07:15' => '7:15 am', '07:30' => '7:30 am', '07:45' => '7:45 am', '08:00' => '8:00 am', '08:15' => '8:15 am',
						   '08:30' => '8:30 am', '08:45' => '8:45 am', '09:00' => '9:00 am', '09:15' => '9:15 am', '09:30' => '9:30 am', '09:45' => '9:45 am', '10:00' => '10:00 am',
						   '10:15' => '10:15 am', '10:30' => '10:30 am', '10:45' => '10:45 am', '11:00' => '11:00 am', '11:15' => '11:15 am', '11:30' => '11:30 am', '11:45' => '11:45 am',
						   '12:00' => '12:00 pm', '12:15' => '12:15 pm', '12:30' => '12:30 pm', '12:45' => '12:45 pm', '13:00' => '1:00 pm', '13:15' => '1:15 pm', '13:30' => '1:30 pm',
						   '13:45' => '1:45 pm', '14:00' => '2:00 pm', '14:15' => '2:15 pm', '14:30' => '2:30 pm', '14:45' => '2:45 pm', '15:00' => '3:00 pm', '15:15' => '3:15 pm',
						   '15:30' => '3:30 pm', '15:45' => '3:45 pm', '16:00' => '4:00 pm', '16:15' => '4:15 pm', '16:30' => '4:30 pm', '16:45' => '4:45 pm', '17:00' => '5:00 pm',
						   '17:15' => '5:15 pm', '17:30' => '5:30 pm', '17:45' => '5:45 pm', '18:00' => '6:00 pm', '18:15' => '6:15 pm', '18:30' => '6:30 pm', '18:45' => '6:45 pm',
						   '19:00' => '7:00 pm', '19:15' => '7:15 pm', '19:30' => '7:30 pm', '19:45' => '7:45 pm', '20:00' => '8:00 pm', '20:15' => '8:15 pm', '20:30' => '8:30 pm',
						   '20:45' => '8:45 pm', '21:00' => '9:00 pm', '21:15' => '9:15 pm', '21:30' => '9:30 pm', '21:45' => '9:45 pm', '22:00' => '10:00 pm', '22:15' => '10:15 pm',
						   '22:30' => '10:30 pm', '22:45' => '10:45 pm', '23:00' => '11:00 pm', '23:15' => '11:15 pm', '23:30' => '11:30 pm', '23:45' => '11:45 pm' );
			
			// ------------------------------------------
			// a option section for options appointment -
			// ------------------------------------------
			$options[]      = array(
			  'name'        => 'appointment',
			  'title'       => esc_html__('Appointment', 'psychiatrist-doctor'),
			  'icon'        => 'fa fa-calendar',
			  'sections' => array(
			
				// -----------------------------
				// begin: appointment settings -
				// -----------------------------
				array(
				  'name'      => 'appointment_setings',
				  'title'     => 'Settings',
				  'icon'      => 'fa fa-gear',
			
					'fields'      => array(
			
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Business Hour's Settings", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'id'        => 'appointment_fs1',
						'type'      => 'fieldset',
						'title'     => 'Monday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_monday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_monday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
						'default'   => array(
						  'dt_company_monday_start'  => '08:00',
						  'dt_company_monday_end' 	 => '17:00',
						)
					  ),
					  
					  array(
						'id'        => 'appointment_fs2',
						'type'      => 'fieldset',
						'title'     => 'Tuesday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_tuesday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_tuesday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
						'default'   => array(
						  'dt_company_tuesday_start'  => '08:00',
						  'dt_company_tuesday_end'    => '17:00',
						)
					  ),		
			
					  array(
						'id'        => 'appointment_fs3',
						'type'      => 'fieldset',
						'title'     => 'Wednesday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_wednesday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_wednesday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
						'default'   => array(
						  'dt_company_wednesday_start'  => '08:00',
						  'dt_company_wednesday_end'    => '17:00',
						)
					  ),
			
					  array(
						'id'        => 'appointment_fs4',
						'type'      => 'fieldset',
						'title'     => 'Thursday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_thursday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_thursday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
						'default'   => array(
						  'dt_company_thursday_start'  => '08:00',
						  'dt_company_thursday_end'    => '17:00',
						)
					  ),
			
					  array(
						'id'        => 'appointment_fs5',
						'type'      => 'fieldset',
						'title'     => 'Friday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_friday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_friday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
						'default'   => array(
						  'dt_company_friday_start'  => '08:00',
						  'dt_company_friday_end'    => '17:00',
						)
					  ),
			
					  array(
						'id'        => 'appointment_fs6',
						'type'      => 'fieldset',
						'title'     => 'Saturday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_saturday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_saturday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
					  ),
			
					  array(
						'id'        => 'appointment_fs7',
						'type'      => 'fieldset',
						'title'     => 'Sunday',
						'fields'    => array(
			
						  array(
							'id'    => 'dt_company_sunday_start',
							'type'  => 'select',
							'title'        => 'From:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						  array(
							'id'    => 'dt_company_sunday_end',
							'type'  => 'select',
							'title'        => 'To:',
							'options'      => $timearray,
							'class'        => 'chosen',
						  ),
			
						),
					  ),
			
					),
				),
			
				// -----------------------------
				// begin: appointment payment -
				// -----------------------------
				array(
				  'name'      => 'appointment_payments',
				  'title'     => 'Payments',
				  'icon'      => 'fa fa-money',
			
					'fields'      => array(
			
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Payment Settings", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'id'         => 'appointment-currency',
						'type'       => 'select',
						'title'      => 'Currency',
						'options'    => psychiatrist_currency_with_symbol(),
						'class'      => 'chosen',
						'default'    => 'USD',
					  ),
			
					  array(
						'id'  		 => 'enable-pay-at-arrival',
						'type'  	 => 'switcher',
						'title' 	 => 'Enable Pay at Arrival',
						'info'		 => 'You can enable pay at arrival option to pay locally'
					  ),
			
					  array(
						'id'  		 => 'enable-paypal',
						'type'  	 => 'switcher',
						'title' 	 => 'Enable PayPal',
						'info'		 => 'You can enable paypal express checkout'
					  ),
			
					  array(
						'id'  		 => 'paypal-username',
						'type'  	 => 'text',
						'title' 	 => 'Business Account Username',
						'info'		 => 'Enter a valid Merchant account ID or PayPal account email address. All payments will go to this account.',
						'dependency' => array( 'enable-paypal', '==', 'true' ),
					  ),
			
					  array(
						'id'  		 => 'enable-paypal-live',
						'type'  	 => 'switcher',
						'title' 	 => 'Enable Live',
						'info'		 => 'You can enable live paypal express checkout.',
						'dependency' => array( 'enable-paypal', '==', 'true' ),
					  ),
			
					),
				),	
			
				// ----------------------------------
				// begin: appointment notifications -
				// ----------------------------------
				array(
				  'name'      => 'appointment_notifications',
				  'title'     => 'Notifications',
				  'icon'      => 'fa fa-info-circle',
			
					'fields'      => array(
			
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Notification Settings", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'id'  		 => 'notification_sender_name',
						'type'  	 => 'text',
						'title' 	 => 'Sender Name',
						'default'	 => get_option( 'blogname' ),
					  ),
			
					  array(
						'id'  		 => 'notification_sender_email',
						'type'  	 => 'text',
						'title' 	 => 'Sender Email ID',
						'default'	 => get_option( 'admin_email' ),
					  ),
			
					  array(
						'type'    => 'notice',
						'class'   => 'info',
						'content' => 'To send scheduled agenda please execute following script with your cron, <b>'.WP_PLUGIN_DIR.'/designthemes-doctor-addon/reservation/cron/send_agenda_cron.sh'.'</b>',
					  ),
			
					  // ------------------------------------------
					  // a option sub section for admin template  -
					  // ------------------------------------------
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Admin Email Template", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the admin about new Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_admin_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [ADMIN_NAME] , New booking information ( Booking id: [APPOINTMENT_ID] )',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_admin_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [ADMIN_NAME], </p>
			<p> New Booking id : [APPOINTMENT_ID] </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>Client Amount to pay : [AMOUNT]</p>
			<p>Staff Name: [STAFF_NAME]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the admin regarding modified Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_admin_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [ADMIN_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Modified',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_admin_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [ADMIN_NAME], </p>
			<p> New Booking id : [APPOINTMENT_ID] </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>Client Amount to pay : [AMOUNT]</p>
			<p>Staff Name: [STAFF_NAME]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
					  
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the admin regarding Deleted / Declined Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_admin_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [ADMIN_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Deleted / Declined',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_admin_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [ADMIN_NAME], </p>
			<p> New Booking id : [APPOINTMENT_ID] </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>Client Amount to pay : [AMOUNT]</p>
			<p>Staff Name: [STAFF_NAME]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
			
					  // ------------------------------------------
					  // a option sub section for staff template  -
					  // ------------------------------------------
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Staff Email Template", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>New Appoinment Notification:</b>',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_staff_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [STAFF_NAME] , New booking information ( Booking id: [APPOINTMENT_ID] )',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_staff_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [STAFF_NAME], </p>
			<p> Your new Booking id : [APPOINTMENT_ID] </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
					  
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the staff regarding modified Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_staff_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [STAFF_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Modified',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_staff_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [STAFF_NAME], </p>
			<p> Your Booking id : [APPOINTMENT_ID]  was modified </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the staff regarding Deleted / Declined Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_staff_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [STAFF_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Deleted / Declined',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_staff_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [STAFF_NAME], </p>
			<p> Booking id : [APPOINTMENT_ID]  was Deleted / Declined </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>Client Name: [CLIENT_NAME]</p>
			<p>Client Phone: [CLIENT_PHONE]</p>
			<p>Client Email: [CLIENT_EMAIL]</p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Evening notification with the next day agenda to Staff Member:</b>',
					  ),
			
					  array(
						'id'  		 => 'agenda_to_staff_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [STAFF_NAME] , Your Agenda for [TOMORROW]',
					  ),
			
					  array(
						'id'  		 => 'agenda_to_staff_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 2,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [STAFF_NAME], </p><p>Your agenda for tomorrow is </p><p>[TOMORROW_AGENDA]</p>',
					  ),
			
					  // --------------------------------------------
					  // a option sub section for cusomer template  -
					  // --------------------------------------------
					  array(
						'type'    => 'subheading',
						'content' => esc_html__( "Customer Email Template", 'psychiatrist-doctor' ),
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the client about new Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_client_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [CLIENT_NAME] , New booking information ( Booking id: [APPOINTMENT_ID] )',
					  ),
			
					  array(
						'id'  		 => 'appointment_notification_to_client_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [CLIENT_NAME], </p>
			<p> Your new Booking id : [APPOINTMENT_ID] </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p> Amount to pay : [AMOUNT]</p>
			<p>[APPOINTMENT_BODY]</p>
			<p>Thank you for choosing our company.</p>',
					  ),
			
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the client regarding modified Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_client_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [CLIENT_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Modified',
					  ),
			
					  array(
						'id'  		 => 'modified_appointment_notification_to_client_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [CLIENT_NAME], </p>
			<p> Your Booking id : [APPOINTMENT_ID]  was modified </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p> Amount to pay : [AMOUNT]</p>
			<p>[APPOINTMENT_BODY]</p>
			<p>Thank you for choosing our company.</p>',
					  ),
					  
					  array(
						'type'    => 'content',
						'content' => '<b>Notification to the client regarding Deleted / Declined Appointment:</b>',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_client_subject',
						'type'  	 => 'text',
						'title' 	 => 'Subject',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Hi [CLIENT_NAME] , ( Booking id: [APPOINTMENT_ID] ) - Deleted / Declined',
					  ),
			
					  array(
						'id'  		 => 'deleted_appointment_notification_to_client_message',
						'type'  	 => 'wysiwyg',
						'title' 	 => 'Message',
						'settings' => array(
						  'textarea_rows' => 5,
						  'tinymce'       => false,
						  'media_buttons' => false,
						),
						'default'	 => '<p> Hello [CLIENT_NAME], </p>
			<p> Your Booking id : [APPOINTMENT_ID]  was Deleted / Declined </p>
			<p> Service: [SERVICE]</p>
			<p> Date & Time: [APPOINTMENT_DATE] - [APPOINTMENT_TIME] </p>
			<p>[APPOINTMENT_BODY]</p>',
					  ),
			
					  array(
						'id'  		 => 'success_message',
						'type'  	 => 'text',
						'title' 	 => 'Success Message',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Success. You got a appointment to experience our excellent service.',
					  ),
			
					  array(
						'id'  		 => 'error_message',
						'type'  	 => 'text',
						'title' 	 => 'Error Message',
						'attributes' => array(
						  'style'    => 'width: 100%;'
						),
						'default'	 => 'Oops! You have cancelled the payment process :',
					  ),
			
					),
				),
			
			  ),
			);

			return $options;
		}
	}
}?>
